import numpy as np
import h5py
import matplotlib.pyplot as plt
import matplotlib.cm as cm
from matplotlib.colors import Normalize
from matplotlib.colors import LogNorm

# set name of file and observation mode
filename='./GPMCOR_DPR_2112070007_0140_044170_L2S_DD2_07A.h5'
mode='FS'

with h5py.File(filename,"r") as infile:
    #convert data to numpy ndarray
    Lat=np.array(infile[mode+'/Latitude'])
    Lon=np.array(infile[mode+'/Longitude'])
    Lon=np.where(Lon >=180.,Lon-360.,Lon)
    precipRateESurf=np.array(infile[mode+'/SLV/precipRateESurface'])
    precipRateAve24=np.array(infile[mode+'/SLV/precipRateAve24'])
    zFactorFinalESurf=np.array(infile[mode+'/SLV/zFactorFinalESurface'])
    # see file specification guide about the directories and parameters
    nscan=Lon.shape[0]  # total number of scan
    nray=Lon.shape[1]   # number of FOV(number of angle)

# python2
# print 'Estimated Surfase Rain at %f,%f: %f'% (Lon[5450][25],Lat[5450][25],precipRateESurf[5450][25]) # precepRateESurface at Scan=5450,FOV=25
# print 'Number of Rainy cells/all: %d/%d'% (len(np.where(precipRateESurf>0)[0]), precipRateESurf.size) 

# python3
print('Estimated Surfase Rain at {0},{1}: {2}'.format(Lon[5450][25],Lat[5450][25],precipRateESurf[5450][25]))
# print('Estimated  2-4km Rain at {0},{1}: {2}'.format(Lon[5450][25],Lat[5450][25],precipRateAve24[5450][25]))

# slicing data. new array contains data of Scan 5350 to 5500 
lon=Lon[5350:5500, :]
lat=Lat[5350:5500, :]
rr=precipRateESurf[5350:5500, :]
rr2=zFactorFinalESurf[5350:5500, :,0]


# calculate statistics of numpy ndarray (for example)
Mean=rr.mean() 
STD=rr.std() 

# set color table
cb=plt.cm.rainbow
cb.set_under('silver')  # Set the color for low out-of-range values.
cb.set_over('black')     # Set the color for high out-of-range values.

# plot with Matplotlib
plt.plot(Lon[5450][25],Lat[5450][25],"+", c='black')
plt.pcolormesh(lon, lat, rr, cmap=cb, norm=LogNorm(vmin=0.1,vmax=100))            # plot in log scale

# use "plt.pcolormesh"
# plt.pcolormesh(lon, lat, rr2, cmap=cb, norm=Normalize(vmin=0,vmax=60))            # plot in linear scale

# use "plt.scatter"
# plt.scatter(lon, lat, s=10, c=rr2, cmap=cb, norm=Normalize(vmin=0, vmax=60))      # plot in linear scale

# use "plt.contourf"
# plt.contourf(lon, lat, rr2, np.linspace(0,60,61), cmap=cb, extend='both')       # plot in linear scale

plt.colorbar(orientation="vertical",extend='both')
plt.show()
plt.close()
