import numpy as np
import matplotlib.pyplot as plt
import matplotlib.cm as cm
from mpl_toolkits.basemap import Basemap

# in case of binary
import gzip
import struct
filename='./gsmap_gauge_now.20211201.0000.dat.gz'
i=0
rain=[0]*3600*1800
with gzip.open(filename, "rb") as f:
    while True:
        data=f.read(4)
        if len(data) < 4:
            break
        rain[i]=struct.unpack('f',data)[0]
        i=i+1
hprecipRateGC=np.reshape(rain, (1800,3600))
# generate meshgrid because GSMaP binary does not contain locations
lo=[5+10*i for i in range(0,3600)]
Lo=0.01*np.array(lo)
la=[8995-10*i for i in range(0,1800)]
La= 0.01*np.array(la)
Lon,Lat=np.meshgrid(Lo,La)
# end of binary case

#plot with Matplotlib
fig=plt.figure(figsize=(20,20))
# set the color interval
interval=list(np.arange(1,30,1)) 
interval.insert(0,0.1)
#set colormap
cmap=cm.jet
cmap.set_under('w', alpha=0)

#set map
m=Basemap(projection='cyl',
         resolution='c',
         llcrnrlat=-90, urcrnrlat=90, llcrnrlon=0, urcrnrlon=360)
m.drawcoastlines(color='black')
m.drawmeridians(np.arange(0,360,30))
m.drawparallels(np.arange(-90,90,30))
x,y=m(Lon, Lat) #compute map projection
im=plt.contourf(x,y,hprecipRateGC, interval, cmap=cmap, latlon=True) 
# set colorbar
cb=m.colorbar(im, "right", size="2.5%")

plt.show()
plt.close()
