import numpy as np
import matplotlib.pyplot as plt
import matplotlib.cm as cm
from mpl_toolkits.basemap import Basemap

'''
# in case of HDF
import h5py
h5='./GPMMRG_MAP_1702010000_H_L3S_MCH_04B.h5'

with h5py.File(h5,"r") as infile: 
    Lat=np.array(infile['Grid'+'/Latitude']) 
    Lon=np.array(infile['Grid'+'/Longitude'])
    hprecipRateGC=np.array(infile['Grid'+'/hourlyPrecipRateGC'])
# end of HDF case
'''
# in case of netCDF
import netCDF4
nc=netCDF4.Dataset('./GPMMRG_MAP_2112010000_H_L3S_MCN_05A.nc','r')
Lon=nc.variables['Longitude'][:,:]
Lat=nc.variables['Latitude'][:,:]
hprecipRateGC=nc.variables['hourlyPrecipRateGC'][:,:]
nc.close()
# end of netCDF case

#plot with Matplotlib
fig=plt.figure(figsize=(20,20))
# set the color interval
interval=list(np.arange(1,30,1)) 
interval.insert(0,0.1)
#set colormap
cmap=cm.jet
cmap.set_under('w', alpha=0)

#set map
m=Basemap(projection='cyl',
         resolution='c',
         llcrnrlat=-90, urcrnrlat=90, llcrnrlon=-180, urcrnrlon=180)
m.drawcoastlines(color='black')
m.drawmeridians(np.arange(0,360,30))
m.drawparallels(np.arange(-90,90,30))
x,y=m(Lon, Lat) #compute map projection
im=plt.contourf(x,y,hprecipRateGC, interval, cmap=cmap, latlon=True) 
# set colorbar
cb=m.colorbar(im, "right", size="2.5%")

plt.show()
plt.close()
